/* Syntax: 
 * CREATE TEMP-TABLE handle [IN WIDGET-POOL widget-pool-name]
 */

DEFINE VARIABLE tth           AS HANDLE    NO-UNDO.
DEFINE VARIABLE bh            AS HANDLE    NO-UNDO.
DEFINE VARIABLE qh            AS HANDLE    NO-UNDO.
DEFINE VARIABLE buf-ord-hndl  AS HANDLE    NO-UNDO.
DEFINE VARIABLE fld1          AS HANDLE    NO-UNDO.
DEFINE VARIABLE fld2          AS HANDLE    NO-UNDO.
DEFINE VARIABLE wg-pool-name  AS CHARACTER NO-UNDO INIT "wg-pool-name".

/* Get database table handles */
buf-ord-hndl = BUFFER Customer:HANDLE.

/* Create an empty, undefined TEMP-TABLE */
CREATE TEMP-TABLE tth IN WIDGET-POOL wg-pool-name.
DELETE OBJECT tth.

CREATE TEMP-TABLE tth IN WIDGET-POOL "wg-pool-name".
DELETE OBJECT tth.

/* 3rd time is a charm: :) again!*/
CREATE TEMP-TABLE tth.

/* Give it Order table's fields & indexes */
tth:CREATE-LIKE(buf-ord-hndl).
/* TODO: add CREATE-LIKE-SEQUENTIAL() method ? */

/* create a new field */
tth:ADD-NEW-FIELD("intField1", "int64").
tth:ADD-NEW-FIELD("intField2", "int", 2, "format", "initial", "label", "column-label").

/* create a new index */
tth:ADD-NEW-INDEX("index-name-1").
tth:ADD-NEW-INDEX("index-name-2", true, false, false).

/* Add field like SalesRep.RepName */
tth:ADD-LIKE-FIELD("Name", "Customer.Name").
tth:ADD-LIKE-FIELD("id",   "Customer.id").
tth:ADD-LIKE-FIELD(buf-ord-hndl:NAME, buf-ord-hndl).

tth:ADD-LIKE-INDEX("abidx","name","Customer").

/* No more fields will be added */
tth:TEMP-TABLE-PREPARE("ordx").

/* Get the buffer handle for the temp-table */
bh = tth:DEFAULT-BUFFER-HANDLE.

bh:BUFFER-CREATE.
bh:BUFFER-COPY(buf-ord-hndl).

/* Run a query to access the TEMP-TABLE */
CREATE QUERY qh.
qh:SET-BUFFERS(bh).
qh:QUERY-PREPARE("FOR EACH ordx WHERE ordx.OrderNum < 50 BY ordx.RepName").
qh:QUERY-OPEN().
fld1 = bh:BUFFER-FIELD(1). /* this is "OrderNum" */
fld2 = bh:BUFFER-FIELD("RepName").

/* just for test */
DEFINE VARIABLE browser AS HANDLE NO-UNDO.
/* CREATE BROWSE browser.  not implemented yet */
DISPLAY browser:BUFFER-FIELD.

/* Display the order number and the salesrep name */
REPEAT:
   qh:GET-NEXT().
   IF qh:QUERY-OFF-END THEN 
      LEAVE.
   DISPLAY STRING(fld1:BUFFER-VALUE()) FORMAT "X(10)".
   DISPLAY STRING(fld2:BUFFER-VALUE()) FORMAT "X(20)".
END.

/* cleanup */ 
qh:QUERY-CLOSE().
bh:BUFFER-RELEASE().
DELETE OBJECT tth.
DELETE OBJECT qh.
